@@ -1,5 +1,5 @@
 #
-# $Id: Offline.pm,v 453864a37ab6 2018/05/01 07:25:03 gomor $
+# $Id: Offline.pm,v a93481b098ec 2020/05/01 08:55:56 gomor $
 #
 package Net::Frame::Dump::Offline;
 use strict;
@@ -37,7 +37,7 @@ sub _setFilter {
    }
 
    my $filter;
-   Net::Pcap::compile($self->_pcapd, \$filter, $str, 0, 0);
+   Net::Pcap::compile($self->_pcapd, \$filter, $str, $self->filterCodeOptimizer, 0);
    if (!defined($filter)) {
       print("[-] ".__PACKAGE__.": Net::Pcap::compile: error\n");
       return;
@@ -199,7 +199,7 @@ Patrice E<lt>GomoRE<gt> Auffret
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2006-2018, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2006-2020, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of the Artistic license.
 See LICENSE.Artistic file in the source distribution archive.
